.ProseMirror{padding:1rem 1.75rem;outline:none!important;font-family:-apple-system,blinkmacsystemfont,Segoe UI,roboto,oxygen,ubuntu,cantarell,Open Sans,Helvetica Neue,sans-serif;margin:0!important}.ProseMirror *{color:var(--body-fg)!important}.ProseMirror p{font-size:15px!important}.ProseMirror h1{display:block!important;font-size:2em!important;margin-block-start:.67em!important;margin-block-end:.67em!important;margin-inline-start:0px!important;margin-inline-end:0px!important;font-weight:700!important;line-height:1.2!important}.ProseMirror h2{padding:0;display:block!important;font-size:1.5em!important;margin-block-start:.83em!important;margin-block-end:.83em!important;margin-inline-start:0px!important;margin-inline-end:0px!important;font-weight:700!important;background:#fff!important;line-height:1.2!important}.ProseMirror h3{display:block!important;font-size:1.17em!important;margin-block-start:1em!important;margin-block-end:1em!important;margin-inline-start:0px!important;margin-inline-end:0px!important;font-weight:700!important;padding:0!important;line-height:1.2!important}.ProseMirror>*+*{margin-top:.75em!important}.ProseMirror p.is-editor-empty:first-child:before{content:attr(data-placeholder);float:left;color:#a8a8a8;pointer-events:none;height:0}.ProseMirror ol,.ProseMirror ul{padding-left:2.5em!important;margin:.3em 0!important}.ProseMirror ol li,.ProseMirror ul li{position:relative!important;margin:.1em 0!important;padding-left:0!important}.ProseMirror ol li::marker,.ProseMirror ul li::marker{font-size:15px!important;color:var(--body-fg)!important}.ProseMirror ol ol,.ProseMirror ul ul,.ProseMirror ol ul,.ProseMirror ul ol{margin:.1em 0 .1em .5em!important}.ProseMirror{margin:1rem 0}.ProseMirror h1,.ProseMirror h2,.ProseMirror h3,.ProseMirror h4,.ProseMirror h5,.ProseMirror h6{line-height:1.1;text-transform:none;padding:0;background:none!important;border:none!important}.ProseMirror pre{background:#0d0d0d!important;color:#fff!important;font-family:JetBrainsMono,monospace!important;padding:.75rem 1rem!important;border-radius:.5rem!important}.ProseMirror pre code{color:#fff!important;padding:0!important;background:none!important;font-size:.8rem!important}.ProseMirror img{max-width:100%;height:auto}.ProseMirror blockquote{padding-left:1rem;border-left:2px solid rgba(13,13,13,.1)}.ProseMirror hr{border:none;border-top:2px solid rgba(13,13,13,.1);margin:2rem 0!important}.ProseMirror a{text-decoration:underline}.ProseMirror table{border-collapse:collapse;table-layout:fixed;width:100%;margin:0;overflow:hidden}.ProseMirror table td,.ProseMirror table th,.ProseMirror table[show_borders=false]:hover td,.ProseMirror table[show_borders=false]:hover th{min-width:1em;border:2px solid #ced4da;padding:3px 5px;vertical-align:top;box-sizing:border-box;position:relative}.ProseMirror table[show_borders=false] td,.ProseMirror table[show_borders=false] th{border:none;box-sizing:border-box}.ProseMirror table td>*,.ProseMirror table th>*{margin-bottom:0}.ProseMirror table th{font-weight:700;text-align:left;background-color:#f1f3f5}.ProseMirror tr{background-color:#fff!important}.ProseMirror table .selectedCell:after{z-index:2;position:absolute;content:"";inset:0;background:#c8c8ff66;pointer-events:none}.ProseMirror table .column-resize-handle{position:absolute;right:-2px;top:0;bottom:-2px;width:4px;background-color:#adf;pointer-events:none}.tableWrapper{overflow-x:auto}.resize-cursor{cursor:ew-resize;cursor:col-resize}
